@@ -5,6 +5,7 @@ from .clients import (
     gnocchi,
     ironic,
     keystone,
+    manila,
     neutron,
     nova,
     zun,
@@ -25,6 +26,7 @@ __all__ = [
     "gnocchi",
     "ironic",
     "keystone",
+    "manila",
     "neutron",
     "nova",
     "zun",
